#extension GL_OES_EGL_image_external : require
precision mediump float;
uniform samplerExternalOES sTexture;
uniform float useColorF;
const int MAX_HUES_HALF = 180;
uniform float hueLut1[MAX_HUES_HALF];
uniform float hueLut2[MAX_HUES_HALF];
varying vec2 v_CamTexCoordinate;

float rgb2hue(vec4 c) {
    vec4 K = vec4(0.0, -1.0 / 3.0, 2.0 / 3.0, -1.0);
    vec4 p = mix(vec4(c.bg, K.wz), vec4(c.gb, K.xy), step(c.b, c.g));
    vec4 q = mix(vec4(p.xyw, c.r), vec4(c.r, p.yzx), step(p.x, c.r));

    float d = q.x - min(q.w, q.y);
    float e = 1.0e-10;
    return abs(q.z + (q.w - q.y) / (6.0 * d + e));
}

vec4 getGrey(vec4 c) {
    float grey = c.r * 0.3008 + c.g * 0.5898 + c.b * 0.1094;
    return vec4(grey, grey, grey, c.a);
}

void main() {
    vec4 c = texture2D(sTexture, v_CamTexCoordinate);
    float hue = rgb2hue(c);

    float result = 359.0 * hue;
    int index = int(result);
    float isValidF = 0.0;
    if(index >= MAX_HUES_HALF) {
        isValidF = hueLut2[index-MAX_HUES_HALF];
    } else {
        isValidF = hueLut1[index];
    }
    gl_FragColor = useColorF * isValidF * c  + useColorF * (1.0 - isValidF) * getGrey(c)  + (1.0 - useColorF) * c;
}