precision mediump float;
uniform sampler2D uTexture;
uniform vec4 vColor;
const int MAX_COLORS = 10;
const int COLOR_POINTS = 4;
uniform float vHues[MAX_COLORS];
uniform float vOffsets[MAX_COLORS];
varying vec2 vTexPosition;

float rgb2hue(vec4 c) {
    vec4 K = vec4(0.0, -1.0 / 3.0, 2.0 / 3.0, -1.0);
    vec4 p = mix(vec4(c.bg, K.wz), vec4(c.gb, K.xy), step(c.b, c.g));
    vec4 q = mix(vec4(p.xyw, c.r), vec4(c.r, p.yzx), step(p.x, c.r));

    float d = q.x - min(q.w, q.y);
    float e = 1.0e-10;
    return abs(q.z + (q.w - q.y) / (6.0 * d + e));
}

bool isInRange(float a1,float a2, float vOffset) {
return a2 >= 0.0 && ((abs(a1-a2) < vOffset) || (1.0 - max(a1, a2) + min(a1, a2)) < vOffset);
}

vec4 getGrey(vec4 c) {
    float grey = c.r * 0.3008 + c.g * 0.5898 + c.b * 0.1094;
    return vec4(grey, grey, grey, c.a);
}

void main() {
    vec4 c = texture2D(uTexture, vTexPosition);
    int i;
    bool hasColor = vHues[0] >= 0.0;
    if(hasColor) {
        float result = 0.0;
        for(i=0; i < MAX_COLORS; i++) {
            bool isInRange = isInRange(rgb2hue(c), vHues[i], vOffsets[i]);
            float isInRangeF = float(isInRange);
            result = max(result, isInRangeF);
        }
        gl_FragColor = result * c + (1.0-result) * getGrey(c);
    } else {
        gl_FragColor = c;
    }
}